api_phone_has_app = "https://my.irancell.ir/api/gift/v1/refer_a_friend"


api_send_invite ="https://my.irancell.ir/api/gift/v1/refer_a_friend/notify"


api_my_info = "https://my.irancell.ir/api/sim/v1/profile"


api_View_Internet_packages = "https://my.irancell.ir/api/catalog/v2/offers"


api_View_music_default = "https://cdn-ngmy.irancell.ir/config/rbt.json"


api_Viewing_command_codes = "https://cdn-ngmy.irancell.ir/config/ussd.json"