from .client.client import Client

"""
MIT License

Copyright (c) 2025 [Danial Erfan Dost]

Permission is hereby granted, free of charge, to any person obtaining a copy
of this book and associated documentation files (the "Book"), to deal
in the Book without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Book, and to permit persons to whom the Book is furnished to do so,
subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Book.

THE BOOK IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE BOOK OR THE USE OR OTHER DEALINGS IN THE BOOK.
"""

__version__ = "1.0.0"
__author__ = "Danial Erfan Dost"
__github__ = "https://github.com/NOMASKERFAN"
print(__author__)
print(__github__)